React Starter Template
Author: Reactonite
Description: Reactonite starter template page

## Text

This is bold and this is semi bold and this is extra bold. This is italic and this is extra light and this is light and this is regular. Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.

## Headings

# H1: Heading 1
## H2: Heading 2
### H3: Heading 3
#### H4: Heading 4

## List

### Ordered

- Consectetur adipiscing elit
- Integer molestie lorem at massa
- Facilisis in pretium nisl aliquet
- Nulla volutpat aliquam velit

### Number

1. Consectetur adipiscing elit
2. Integer molestie lorem at massa
3. Facilisis in pretium nisl aliquet
4. Nulla volutpat aliquam velit

## Icons

### Social Round

### Basic Icons

## Buttons

### Primary

Primary Large

Primary

Primary Small

### Secondary

Secondary Large

Secondary

Secondary Small

## Inputs

Email address
Email me a copy I am a human
Your message was successfully sent
Your message has not been sent, restart